@@ -42,7 +42,7 @@ impl Input {
     pub fn new<S: AsRef<OsStr>>(path: S) -> Result<Self> {
         let path = path.as_ref();
         if path == "-" {
-            Ok(Input::Stdin(io::stdin()))
+            Ok(Self::std())
         } else {
             #[cfg(feature = "http")]
             if is_http(path) {
@@ -59,6 +59,11 @@ impl Input {
         }
     }
 
+    /// Contructs a new input for stdin
+    pub fn std() -> Self {
+        Input::Stdin(io::stdin())
+    }
+
     /// Contructs a new input either by opening the file or for '-' returning stdin
     ///
     /// The error is converted to a [`OsString`](std::ffi::OsString) so that [stuctopt](https://docs.rs/structopt/latest/structopt/#custom-string-parsers) can show it to the user.
@@ -139,6 +144,13 @@ impl Input {
     }
 }
 
+/// Returns an [`Input`] representing stdin
+impl Default for Input {
+    fn default() -> Self {
+        Self::std()
+    }
+}
+
 impl Read for Input {
     fn read(&mut self, buf: &mut [u8]) -> IoResult<usize> {
         match self {
